#
# spec file for package python-oslo.i18n
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-oslo.i18n
Version:        6.4.0
Release:        1.2
Summary:        OpenStack i18n library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/oslo.i18n
Source0:        https://files.pythonhosted.org/packages/source/o/oslo.i18n/oslo.i18n-6.4.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-stestr
BuildRequires:  python3-testscenarios
BuildArch:      noarch

%description
The oslo.i18n library contain utilities for working with internationalization
(i18n) features, especially translation for text strings in an application
or library.

%package -n python3-oslo.i18n
Summary:        OpenStack i18n library

%description -n python3-oslo.i18n
The oslo.i18n library contain utilities for working with internationalization
(i18n) features, especially translation for text strings in an application
or library.

This package contains the Python 3.x module.

%package -n python-oslo.i18n-doc
Summary:        Documentation for OpenStack i18n library
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-sphinxcontrib-apidoc

%description -n python-oslo.i18n-doc
Documentation for the oslo.i18n library.

%prep
%autosetup -p1 -n oslo.i18n-6.4.0
%py_req_cleanup

%build
%{py3_build}

%install
%{py3_install}

# generate html docs
PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%check
%{openstack_stestr_run}

%files -n python3-oslo.i18n
%license LICENSE
%{python3_sitelib}/oslo_i18n
%{python3_sitelib}/*egg-info

%files -n python-oslo.i18n-doc
%doc doc/build/html ChangeLog CONTRIBUTING.rst README.rst
%license LICENSE

%changelog
* Mon Sep  2 2024 cloud-devel@suse.de
- update to version 6.4.0
  - reno: Update master for unmaintained/victoria
  - Remove old excludes
  - Update master for stable/2024.1
* Sun Mar 24 2024 cloud-devel@suse.de
- update to version 6.3.0
  - Fix leftover `locale.getdefaultlocale` mock
  - Display coverage report
  - Update python classifier in setup.cfg
  - Bump hacking
* Wed Dec 27 2023 cloud-devel@suse.de
- update to version 6.2.0
  - Moves supported python runtimes from version 3.8 to 3.10
  - tox: Remove 'ignore_base_python_conflict'
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
  - Imported Translations from Zanata
  - Update master for stable/2023.1
* Thu Jun 15 2023 Dirk Müller <dmueller@suse.com>
- temporarly disable tests
* Tue Mar  7 2023 cloud-devel@suse.de
- update to version 6.0.0
  - Drop python3.6/3.7 support in testing runtime
  - setup.cfg: Replace dashes by underscores
  - Fix formatting of release list
  - Imported Translations from Zanata
  - Remove unnecessary unicode prefixes
  - Update CI to use unversioned jobs template
* Mon Jun 20 2022 Dirk Müller <dmueller@suse.com>
- drop unused dependencies
* Mon Dec  6 2021 cloud-devel@suse.de
- update to version 5.1.0
  - Changed minversion in tox to 3.18.0
  - Fix requirements issues
  - Update master for stable/victoria
  - Use py3 as the default runtime for tox
  - Remove all usage of six library
  - Use TOX_CONSTRAINTS_FILE
  - Upgrade the pre-commit-hooks version
  - Remove six.PY3
  - Adding pre-commit
  - Add Python3 wallaby unit tests
  - Switch testing to Xena testing runtime
  - Fix hacking min version to 3.0.1
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 5.0.1
  - Imported Translations from Zanata
  - Stop to use the __future__ module.
  - Update master for stable/ussuri
  - Remove a couple more shim tests
  - Add Babel aliases to get_available_languages
  - Bump bandit version
  - Switch to newer openstackdocstheme and reno versions
  - Add Python3 victoria unit tests
  - Add py38 package metadata
  - Remove translation sections from setup.cfg
  - Drop use of babel
  - Remove the unused coding style modules
  - Align contributing doc with oslo's policy
  - Add release notes links to doc index
  - Bump default tox env from py37 to py38
  - Remove Message.translate
* Tue May 12 2020 cloud-devel@suse.de
- update to version 4.0.1
  - Use unittest.mock instead of third party mock
  - tox: Trivial cleanup
  - Update hacking for Python3
  - Deprecate Message.translate in favor of Message.translation
  - remove outdated header
  - Integrate sphinxcontrib-apidoc
  - Imported Translations from Zanata
  - Allow Message.translate to handle unhashable inputs
  - tox: Keeping going with docs
  - Update master for stable/train
  - [ussuri][goal] Drop python 2.7 support and testing
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 3.24.0
  - Cap Bandit below 1.6.0 and update Sphinx requirement
  - Update master for stable/stein
  - Clarify that translation strings are extracted via source inspection
  - Replace git.openstack.org URLs with opendev.org URLs
  - Move doc related modules to doc/requirements.txt
  - Add Python 3 Train unit tests
  - Dropping the py35 testing
  - Fix guidelines w.r.t. translation of log messages
  - OpenDev Migration Patch
  - Move to releases.openstack.org
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 3.23.1
  - Update hacking version
  - Update mailinglist from dev to discuss
  - Remove unused code
  - add lib-forward-testing-python3 test job
  - Override getttext.find to cache result
  - Imported Translations from Zanata
  - Always build universal wheels
  - Update reno for stable/rocky
  - Remove references to log translation functions
  - Clean up .gitignore references to personal tools
  - Don't quote {posargs} in tox.ini
  - Change python3.5 job to python3.7 job on Stein+
  - add python 3.6 unit test job
  - add python 3.7 unit test job
  - import zuul job settings from project-config
  - Use templates for cover and lower-constraints
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 3.21.0
  - Remove stale pip-missing-reqs tox test
  - Add release notes to README.rst
  - set default python to python3
  - fix tox python3 overrides
  - Update reno for stable/queens
  - Update links in README
  - Trivial: Update pypi url to new url
  - Imported Translations from Zanata
  - Remove moxstubout usage
  - add bandit to pep8 job
  - Switch to stestr
  - Updated from global requirements
  - add lower-constraints job
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 3.19.0
  - Imported Translations from Zanata
  - Remove setting of version/release from releasenotes
  - Remove -U from pip install
  - Updated from global requirements
  - Avoid tox_install.sh for constraints support
* Sat Nov 25 2017 cloud-devel@suse.de
- update to version 3.18.0
  - Update reno for stable/pike
  - Imported Translations from Zanata
  - Updated from global requirements
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 3.17.0
  - Revert "Remove Babel as a runtime requirement"
  - Remove Babel as a runtime requirement
  - Enable some off-by-default checks
  - Check reStructuredText documents for common style issues
  - Fix wrong response with language zh-TW.
  - rearrange the documentation to fit into the new standard layout
  - Imported Translations from Zanata
  - add notes about skipping log translation setup
  - [Fix gate]Update test requirement
  - Python 3.5 is added
  - Update reno for stable/ocata
  - turn on warning-is-error in doc build
  - Update URLs in documents according to document migration
  - Updated from global requirements
  - switch from oslosphinx to openstackdocstheme
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 3.12.0:
  - Add Constraints support
  - Typo fix in oslo.i18n
  - Add reno for release notes management
  - Show team and repo badges on README
  - Changed the home-page link
  - Replace six.iteritems() with .items()
  - Add missing dependency testscenarios
  - Updated from global requirements
  - Add docs on how to display translated strings in your app
* Fri Sep  2 2016 tbechtold@suse.com
- update to version 3.9.0
  * Fix parameters of assertEqual are misplaced
  * Updated from global requirements
* Wed Aug 10 2016 tbechtold@suse.com
- - update to version 3.8.0
  * Imported Translations from Zanata
  * Updated from global requirements
  * Don't include openstack/common in flake8 exclude list
* Thu Jun  2 2016 tbechtold@suse.com
- use renderspec source service
- update spec from upstream
* Tue Apr 26 2016 rhafer@suse.de
- update to 3.6.0
  * Updated from global requirements
  * Better isolate tests and fixtures from environment
  * Imported Translations from Zanata
* Thu Mar  3 2016 tbechtold@suse.com
- update to 3.3.0:
  * Update translation setup
  * Updated from global requirements
  * Imported Translations from Zanata
  * Updated from global requirements
  * Updated from global requirements
  * add versionadded designations to newer functions
  * doc: contextual/plural translation requires oslo.i18n >=2.1.0
  * Trival: Remove 'MANIFEST.in'
  * [doc] Update _i18n.py example to pass pep8
  * Add missing blank in usage.rst
  * Remove Python 2.6 workround for logging
  * Drop python 2.6 support
  * Updated from global requirements
  * Remove python 2.6 classifier
  * Remove python 2.6 and cleanup tox.ini
  * Improved integration module documentation
  * Updated from global requirements
  * Imported Translations from Zanata
  * Fix coverage configuration and execution
  * No need for Oslo Incubator Sync
  * Enhance the formatting error robustness patch
  * Imported Translations from Zanata
  * Move 'history' -> release notes section
  * Add shields.io version/downloads links/badges into README.rst
  * Change ignore-errors to ignore_errors
  * Added the home-page value with Oslo wiki
  * Updated from global requirements
- Switch to .spec file from rpm-packaging upstream project
* Wed Sep  9 2015 tbechtold@suse.com
- update to 2.6.0:
  * Updated from global requirements
  * Trap formatting errors
  * Imported Translations from Transifex
  * Clean up _translate_msgid logic a bit
* Fri Jul 31 2015 tbechtold@suse.com
- Unify spec file #2
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file. Use fedora compatible files macros
* Tue Jul 28 2015 tbechtold@suse.com
- update to 2.2.0:
  * Imported Translations from Transifex
  * Updated from global requirements
  * Fix mock use for 1.1.0
  * Add requirements for pre-release test scripts
  * Imported Translations from Transifex
* Wed Jul 15 2015 dmueller@suse.com
- update to 2.1.0:
  * Support contextual and plural form of gettext functions
  * Imported Translations from Transifex
  * clarify translation policy
  * Add tox target to find missing requirements
  * Imported Translations from Transifex
* Wed Jun 24 2015 tbechtold@suse.com
- update to 2.0.0:
  * Updated from global requirements
  * Remove oslo namespace package
* Fri Jun 12 2015 dmueller@suse.com
- Further reducing diff
* Fri Jun 12 2015 tbechtold@suse.com
- Reduce diff between SUSE and RDO packaging:
  * Add extra oslo.i18n-doc package
* Tue Jun  2 2015 tbechtold@suse.com
- update to 1.7.0:
  * Advertise support for Python3.4 / Remove support for Python 3.3
  * Updated from global requirements
  * Misplaced parenthesis causing confusion
  * Remove run_cross_tests.sh
  * Imported Translations from Transifex
  * Uncap library requirements for liberty
  * Standardize setup.cfg summary for oslo libs
  * Updated from global requirements
  * Move to hacking 0.10
  * Update guideline doc of multiple use msg case
* Tue Mar 10 2015 tbechtold@suse.com
- update to 1.5.0:
  * Updated from global requirements
* Tue Feb 24 2015 tbechtold@suse.com
- update to version 1.4.0:
  * Add test fixture to prefix lazily translated messages
* Thu Jan 29 2015 tbechtold@suse.com
- update to version 1.3.1:
  * Clear global cache in test_get_available_languages
  * Make setup.cfg packages include oslo.i18n
* Thu Jan 15 2015 tbechtold@suse.com
- update to version 1.3.0:
  * Add a fixture to let tests manage the lazy flag
  * Fix the link to the bug tracker in the README
- Add python_requires to _service
* Thu Jan  8 2015 tbechtold@suse.com
- update to version 1.2.0:
  * Correct the translation domain for loading messages
  * Move out of the oslo namespace package
  * Workflow documentation is now in infra-manual
  * Force code sample to be treated as python
  * Imported Translations from Transifex
  * Add note for integration modules in libraries
  * Activate pep8 check that _ is imported
  * Add pbr to installation requirements
  * Updated from global requirements
  * Updated from global requirements
  * Remove extraneous vim editor configuration comments
  * Make clear in docs to use _LE() when using LOG.exception()
  * Support building wheels (PEP-427)
  * Imported Translations from Transifex
  * Fix coverage testing
  * Imported Translations from Transifex
  * Use same indentation in doc/source/usage
  * Imported Translations from Transifex
  * Imported Translations from Transifex
  * Updated from global requirements
  * Remove unused/mutable default args
  * Fixes a small syntax error in the doc examples
- Add BuildRequires python-oslotest and run testsuite during build
- Remove BuildRequires python-setuptools
* Sun Sep 21 2014 tbechtold@suse.com
- update to version 1.0.0:
  * Add missing six dependency
- Add Requires for python-Babel and python-six
* Fri Sep 12 2014 dmueller@suse.com
- update to 0.3.0:
  * Imported Translations from Transifex
  * Updated from global requirements
  * Imported Translations from Transifex
  * Document how to add import exceptions
* Tue Aug 26 2014 dmueller@suse.com
- update to 0.2.0:
  * Add a test fixture for translatable strings
  * Imported Translations from Transifex
  * Add Changelog to the documentation
* Thu Jul 24 2014 dmueller@suse.com
- Initial package (0.1.0)
